@@ -1,6 +1,6 @@
 import requests
 
-import constants
+import hoopoe.constants as constants
 
 class Hoopoe:
     def __init__(self, api_key, version, base_url=constants.base_url):
